#
# spec file for package elementary-appcenter
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           elementary-appcenter
Version:        0.2.9
Release:        lp151.2.4
Summary:        Browse and manage apps
License:        GPL-3.0
Group:          System/GUI/Other
URL:            https://elementary.io/
Source:         https://github.com/elementary/appcenter/archive/%{version}.tar.gz#/appcenter-%{version}.tar.gz
# PATCH-FIX-UPSTREAM -- Fix vala compiler errors (#663)
Patch0:         appcenter-0.2.9-vala-0.4.patch
BuildRequires:  cmake
BuildRequires:  elementary-cmake-modules
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  intltool
BuildRequires:  libxml2-tools
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(appstream) >= 0.10.3
BuildRequires:  pkgconfig(appstream-glib)
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gio-2.0) >= 2.46
BuildRequires:  pkgconfig(granite)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.10
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(packagekit-glib2)
BuildRequires:  pkgconfig(vapigen) >= 0.28
Recommends:     %{name}-lang
Recommends:     libzypp-plugin-appdata
Provides:       appcenter = %{version}
Obsoletes:      appcenter < %{version}

%description
AppCenter is a native Gtk+ app store built on AppStream and Packagekit.

%lang_package

%prep
%setup -q -n appcenter-%{version}
%patch0 -p2

sed -i 's/\bmetainfo\b/appdata/' $(grep -rwl 'metainfo')

# Use the system logo
sed -i 's/\(distributor\)-logo/\1/' $(grep -rwl distributor-logo)

%build
%cmake -DGSETTINGS_COMPILE=FALSE -DUSE_UNITY=FALSE
make %{?_smp_mflags}

%install
%cmake_install
%suse_update_desktop_file -r -G AppCenter io.elementary.appcenter GTK System PackageManager
%find_lang io.elementary.appcenter %{name}.lang
%fdupes %{buildroot}%{_datadir}

%post
%glib2_gsettings_schema_post
%desktop_database_post

%postun
%glib2_gsettings_schema_postun
%desktop_database_postun

%files
%doc AUTHORS COPYING
%{_bindir}/io.elementary.appcenter
%{_datadir}/appdata/io.elementary.appcenter.appdata.xml
%{_datadir}/applications/io.elementary.appcenter*.desktop
%{_datadir}/dbus-1/services/io.elementary.appcenter.service
%{_datadir}/glib-2.0/schemas/io.elementary.appcenter.gschema.xml
%dir %{_sysconfdir}/io.elementary.appcenter
%config %{_sysconfdir}/io.elementary.appcenter/appcenter.blacklist

%files lang -f %{name}.lang

%changelog
* Sun Mar 25 2018 avvissu@yandex.by
-  Fix vala compiler errors (appcenter-0.2.9-vala-0.4.patch)
* Fri Mar  2 2018 avvissu@yandex.by
- Update to 0.2.9:
  * Add OARS data (#628)
  * use houston to test appcenter (#616)
  * Update categories with new palette (#614)
  * Don't parse the os-update version as it is showing the number
    of available updates (#620)
- Use the system logo
* Tue Jan 30 2018 avvissu@yandex.by
- Update to 0.2.8:
  * Remove a duplicated line (#589)
  * Show humblebutton on attempting to update unpaid applications
    (#561)
- Rename the package: appcenter > elementary-appcenter
* Tue Nov 21 2017 avvissu@yandex.by
- Update to 0.2.7:
  * Clean up config.vala.in
  * Rename config.vala.cmake to config.vala.in
  * Rename DbusInterfaces.vala to DBusInterfaces.vala (#542)
  * Use string.length rather than string.len (#534)
  * Remove app_icon (#533)
  * Add package information to OS Updates details (#518)
  * Style cache update fail dialog details as Terminal (#530)
  * Show an error when updating cache failed (#503)
  * Banner CSS Fixes (#521)
  * Move CSS to application.css (#519)
* Mon Sep 18 2017 avvissu@yandex.by
- Update to 0.2.6:
  * Restore daemon desktop file (#474)
  * RDN command on readme (#473)
* Fri Aug  4 2017 avvissu@yandex.by
- Update to 0.2.5:
  * Fix update view sort order (#435)
  * Restore debug command line option (#431)
  * Fix fatal exception in UpdateManager (#425)
  * Split AppListView and AppListUpdateView into two files (#426)
  * Add a paragraph about loading local XML files to README (#427)
  * Clean up AbstractAppList and AppListView (#418)
  * Fix sorting in AppListView (#419)
  * Blacklist apps (#409)
  * fix category items (#402)
* Fri Jul 21 2017 avvissu@yandex.by
- Update to 0.2.4:
  * Fix get_style_valist crashes (#380)
  * Fix threads crash (#381)
  * Don't show share popover for OS updates (#373)
  * Homepage.vala: get_app_ids cleanups (#372)
  * Make share popover its own class, add more networks (#346)
  * Show a spinner when the backend is working on something (#370)
  * Remove maximum size restriction (#371)
  * Remove About dialog (#361)
  * appdata: update bug tracker URL (#363)
  * Add screenshot to appdata (#362)
  * Use destroy instead of remove (#358)
  * Create is_native in Package.vala and use in AppListView.vala
  * AppInfoView: make project license a link (#357)
  * AppInfoView.vala: connect to correct widget for copy link
  * Update AppListView to display ElementaryOS apps as curated apps
  * Remove icons that are required by fdo icon spec (#349)
  * AppInfoView.vala: code style and simplify (#339)
  * Add project license to footer (#344)
- Change the sourceurl to git
* Thu Jun  1 2017 avvissu@yandex.by
- Update to 0.2.3:
  * Load more screenshots (#325)
  * Fix AppCenter crash with empty package cache (#321)
* Thu May 25 2017 avvissu@yandex.by
- Update to 0.2.2:
  * Allow putting a slash for the date (#298)
  * revert to last known good rev
    'refs/remotes/origin/master'
  * update po files
* Sun May 21 2017 avvissu@yandex.by
- Update to 0.2.1:
  * Provide a custom error message from stripe (#282)
  * Move the banner left and right (#287)
* Wed May 17 2017 avvissu@yandex.by
- Update to 0.2:
  * update translation template
  * Add privacy info (#273)
  * Synchronously register the DBus interface (#256)
  * Add screenshot and tagline (#272)
  * fix broken translations link (#267)
  * Don't put an author name on system updates (#253)
  * Merge remote-tracking branch 'origin/master'
  * Translated using Weblate (Japanese)
  * Translated using Weblate (Portuguese (Brazil))
  * Translated using Weblate (Dutch)
  * Translated using Weblate (English (United Kingdom))
  * ...
* Fri Mar 17 2017 avvissu@yandex.by
- Update to 0.1.4:
  * appdata: minor string updates
  * Add release information to the AppData.xml
  * Fix open button appearing on apps which cannot be launched
  * Trigger search if "appstream://" URL is not recognised.
  * Set a minimum size for the main window.
  * Use lazy loading of apps in categories and search.
  * This removes the limit of results that can appear in the
    search view.
  * Show package versions in update tabs instead of summary
  * Show the version of available updates in the info view
    instead of installed version
  * Remove unused AppCellRenderer.vala
  * Updated translation template
  * Add open button to open apps from appcenter
  * Use GObject-style construction
  * Cache properties
  * Fix link handling so that it shows the package even if the
    window is already shown
  * Add support for appstream links
  * Quit on Ctrl + Q
* Wed Dec  7 2016 avvissu@yandex.by
- Update to 0.1.3:
  * Fix crash with appstream entries that have no package
  * Use one task accross the class
  * Fix code-style issues
  * Cache used members / variables
- Spec file cleanup
* Sun Oct 30 2016 mailaender@opensuse.org
- update to version 0.1.2
* Sun Oct  2 2016 mailaender@opensuse.org
- update to version 0.1.1
- recommend libzypp-plugin-appdata
* Sat Sep 10 2016 mailaender@opensuse.org
- update to stable version 0.1
* Fri May  6 2016 mailaender@opensuse.org
- update to version 0.1+r193
* Sat Sep 26 2015 and.november@opensuse.org
- initial package (version 0.1+r2) for build.opensuse.org
